@@ -31,8 +31,13 @@ class ringcentral:
   def get_account_details(self, account_id='~'):
     result = self.platform.get(f"/restapi/v1.0/account/{account_id}")
     wait = 1
-    while Utils.is_retryable(result.response().status_code):
-      print(f"retrying. last result: {result}")
+    while (
+        Utils.is_retryable(result.response().status_code)
+        or 'Request rate exceeded' in str(result.error())
+        or '429' in str(result.error())
+    ):
+      print(f"retrying. last result: {result} {result.error()}")
+      print(f"headers: {result.response().headers}")
       time.sleep(wait)
       wait = wait * 2 if wait < 10 else 10
       result = self.platform.get(f"/restapi/v1.0/account/{account_id}")
@@ -54,8 +59,13 @@ class ringcentral:
     }
     result = self.platform.post(f"/restapi/v1.0/account/~/extension/{extension}/sms", post_body)
     wait = 1
-    while Utils.is_retryable(result.response().status_code):
-      print(f"retrying. last result: {result}")
+    while (
+        Utils.is_retryable(result.response().status_code)
+        or 'Request rate exceeded' in str(result.error())
+        or '429' in str(result.error())
+    ):
+      print(f"retrying. last result: {result} {result.error()}")
+      print(f"headers: {result.response().headers}")
       time.sleep(wait)
       wait = wait * 2 if wait < 10 else 10
       result = self.platform.post(f"/restapi/v1.0/account/~/extension/{extension}/sms", post_body)
@@ -66,8 +76,13 @@ class ringcentral:
   def renew_webhook(self, subscription_id):
     result = self.platform.post(f"/restapi/v1.0/subscription/{subscription_id}/renew")
     wait = 1
-    while Utils.is_retryable(result.response().status_code):
-      print(f"retrying. last result: {result}")
+    while (
+        Utils.is_retryable(result.response().status_code)
+        or 'Request rate exceeded' in str(result.error())
+        or '429' in str(result.error())
+    ):
+      print(f"retrying. last result: {result} {result.error()}")
+      print(f"headers: {result.response().headers}")
       time.sleep(wait)
       wait = wait * 2 if wait < 10 else 10
       result = self.platform.post(f"/restapi/v1.0/subscription/{subscription_id}/renew")
@@ -81,8 +96,13 @@ class ringcentral:
       query_params['dialingPlan'] = dialing_plan
     result = self.platform.post(f"/restapi/v1.0/account/~/extension/~/address-book/contact", contact, query_params)
     wait = 1
-    while Utils.is_retryable(result.response().status_code):
-      print(f"retrying. last result: {result}")
+    while (
+        Utils.is_retryable(result.response().status_code)
+        or 'Request rate exceeded' in str(result.error())
+        or '429' in str(result.error())
+    ):
+      print(f"retrying. last result: {result} {result.error()}")
+      print(f"headers: {result.response().headers}")
       time.sleep(wait)
       wait = wait * 2 if wait < 10 else 10
       result = self.platform.post(f"/restapi/v1.0/account/~/extension/~/address-book/contact", contact, query_params)
@@ -104,8 +124,13 @@ class ringcentral:
       query_params['phoneNumber'] = phone_number
     result = self.platform.get(f"/restapi/v1.0/account/~/extension/~/address-book/contact", query_params)
     wait = 1
-    while Utils.is_retryable(result.response().status_code):
-      print(f"retrying. last result: {result}")
+    while (
+        Utils.is_retryable(result.response().status_code)
+        or 'Request rate exceeded' in str(result.error())
+        or '429' in str(result.error())
+    ):
+      print(f"retrying. last result: {result} {result.error()}")
+      print(f"headers: {result.response().headers}")
       time.sleep(wait)
       wait = wait * 2 if wait < 10 else 10
       result = self.platform.get(f"/restapi/v1.0/account/~/extension/~/address-book/contact", query_params)
@@ -116,8 +141,13 @@ class ringcentral:
   def get_contact(self, contact_id):
     result = self.platform.get(f"/restapi/v1.0/account/~/extension/~/address-book/contact/{contact_id}")
     wait = 1
-    while Utils.is_retryable(result.response().status_code):
-      print(f"retrying. last result: {result}")
+    while (
+        Utils.is_retryable(result.response().status_code)
+        or 'Request rate exceeded' in str(result.error())
+        or '429' in str(result.error())
+    ):
+      print(f"retrying. last result: {result} {result.error()}")
+      print(f"headers: {result.response().headers}")
       time.sleep(wait)
       wait = wait * 2 if wait < 10 else 10
       result = self.platform.get(f"/restapi/v1.0/account/~/extension/~/address-book/contact/{contact_id}")
@@ -131,8 +161,13 @@ class ringcentral:
       query_params['dialingPlan'] = dialing_plan
     result = self.platform.put(f"/restapi/v1.0/account/~/extension/~/address-book/contact/{contact_id}", contact, query_params)
     wait = 1
-    while Utils.is_retryable(result.response().status_code):
-      print(f"retrying. last result: {result}")
+    while (
+        Utils.is_retryable(result.response().status_code)
+        or 'Request rate exceeded' in str(result.error())
+        or '429' in str(result.error())
+    ):
+      print(f"retrying. last result: {result} {result.error()}")
+      print(f"headers: {result.response().headers}")
       time.sleep(wait)
       wait = wait * 2 if wait < 10 else 10
       result = self.platform.put(f"/restapi/v1.0/account/~/extension/~/address-book/contact/{contact_id}", contact, query_params)
@@ -143,8 +178,13 @@ class ringcentral:
   def delete_contact(self, contact_id):
     result = self.platform.delete(f"/restapi/v1.0/account/~/extension/~/address-book/contact/{contact_id}")
     wait = 1
-    while Utils.is_retryable(result.response().status_code):
-      print(f"retrying. last result: {result}")
+    while (
+        Utils.is_retryable(result.response().status_code)
+        or 'Request rate exceeded' in str(result.error())
+        or '429' in str(result.error())
+    ):
+      print(f"retrying. last result: {result} {result.error()}")
+      print(f"headers: {result.response().headers}")
       time.sleep(wait)
       wait = wait * 2 if wait < 10 else 10
       result = self.platform.delete(f"/restapi/v1.0/account/~/extension/~/address-book/contact/{contact_id}")
@@ -167,8 +207,13 @@ class ringcentral:
       post_body['perPage'] = per_page
     result = self.platform.post(f"/restapi/v1.0/account/~/directory/entries/search", post_body)
     wait = 1
-    while Utils.is_retryable(result.response().status_code):
-      print(f"retrying. last result: {result}")
+    while (
+        Utils.is_retryable(result.response().status_code)
+        or 'Request rate exceeded' in str(result.error())
+        or '429' in str(result.error())
+    ):
+      print(f"retrying. last result: {result} {result.error()}")
+      print(f"headers: {result.response().headers}")
       time.sleep(wait)
       wait = wait * 2 if wait < 10 else 10
       result = self.platform.post(f"/restapi/v1.0/account/~/directory/entries/search", post_body)
